\name{rpuHclust}
\alias{rpuHclust}
\title{Hierarchical Clustering}

\description{
     This function finds hierarchical clusters from a distance
     matrix based an agglomerative algorithms.
}

\usage{
     rpuHclust(d, method="complete", members=NULL)
}

\details{
    Perform hierarchical clusterings with the rpudplus add-on for rpud. 
    In absense of rpudplus, rpud perform the cluster analysis with the 
    default R implementation, and there will be no speed gain.
}

\arguments{
      \item{d}{a dissimilarity structure as produced by \code{dist} or \code{rpuDist}.}

      \item{method}{the agglomeration method to be used. This should
        be (an unambiguous abbreviation of) one of
        \code{"ward"}, \code{"single"}, \code{"complete"},
        \code{"average"}, \code{"mcquitty"}, \code{"median"} or
        \code{"centroid"}.}

      \item{members}{\code{NULL} or a vector with length size of
        \code{d}. See the \sQuote{Details} section.}
}

\value{
    An object of class \bold{hclust} which describes the
    tree produced by the clustering process.
}

\seealso{
    hclust, gpuHclust
}

\examples{
\dontrun{
    numVectors <- 5
    dimension <- 10
    Vectors <- matrix(runif(numVectors*dimension), numVectors, dimension)
    distMat <- rpuDist(Vectors, "euclidean")
    myClust <- rpuHclust(distMat, "single")
    plot(myClust)
}}

\keyword{multivariate}
\keyword{cluster}

