\name{write.rpusvm} 
\alias{write.rpusvm}
\title{SVM Model File Export}
\description{
  The \code{wite.rpusvm} method exports a SVM model created
  by \code{rpusvm} to a file.
  
  In the non-free \code{rpudplus} add-on, the \code{rpusvm} method
  is implemented in NVIDIA CUDA, and assumes necessary
  double precision CUDA hardware support. The SVM
  model thus trained assumes ascending classification label ordering,
  and has an independent \code{sigma} coefficient for
  probabilistic regression. It also includes possible scaling parameters.
  Hence it is incompatible with the SVM model created by \code{e1071}.

  Despite the incompatibility of the SVM models, \code{rpusvm} 
  supports equivalent LIBSVM functionality in \code{e1071}.

  This method is not supported in the free \code{rpud} package.
}
\usage{
write.rpusvm(object, rpusvm.file = "Rdata.rpusvm")
}
\arguments{
  \item{object}{An S3 object that inherits from \code{rpusvm} class.}
  \item{rpusvm.file}{filename to export the \code{rpusvm} object to.}
}
\details{
  Note: The SVM model files created by \code{e1071} and 
  \code{rpusvm} are *incompatible*.
}
\author{
  Chi Yau (based on R doc of \code{write.svm} in \code{e1071} by Tomomi TAKASHINA)\cr
  \email{chi.yau@r-tutor.com}
}
\seealso{
  \code{\link{rpusvm}}
}
\examples{
\dontrun{
data(iris)
attach(iris)

## classification mode
# default with factor response:
model <- rpusvm (Species~., data=iris)

# export SVM object to file
write.rpusvm(model, rpusvm.file = "iris-classifier.rpusvm")

}}
\keyword{neural}
\keyword{nonlinear}
\keyword{classif}


